aboutsummaryrefslogtreecommitdiffstats
path: root/fetchmail.c
diff options
context:
space:
mode:
authorEric S. Raymond <esr@thyrsus.com>1998-07-20 04:00:41 +0000
committerEric S. Raymond <esr@thyrsus.com>1998-07-20 04:00:41 +0000
commit43a5237c12a70acaaabe878e745e59843ee69cee (patch)
tree38b9ac4772c7dabdc6b72e34b4762167b720c6db /fetchmail.c
parent14a81d42fedb126c9f58508144d1c9bcfcb9cc04 (diff)
downloadfetchmail-43a5237c12a70acaaabe878e745e59843ee69cee.tar.gz
fetchmail-43a5237c12a70acaaabe878e745e59843ee69cee.tar.bz2
fetchmail-43a5237c12a70acaaabe878e745e59843ee69cee.zip
GSSAPI support is rockin'!
svn path=/trunk/; revision=1979
Diffstat (limited to 'fetchmail.c')
-rw-r--r--fetchmail.c15
1 files changed, 12 insertions, 3 deletions
diff --git a/fetchmail.c b/fetchmail.c
index 148d175a..b91e4765 100644
--- a/fetchmail.c
+++ b/fetchmail.c
@@ -159,6 +159,9 @@ int main (int argc, char **argv)
#ifndef IMAP_ENABLE
printf("-IMAP");
#endif /* IMAP_ENABLE */
+#ifdef GSSAPI
+ printf("+IMAP-GSS");
+#endif /* GSSAPI */
#ifdef RPA_ENABLE
printf("+RPA");
#endif /* RPA_ENABLE */
@@ -1163,9 +1166,15 @@ void dump_params (struct runctl *runp, struct query *querylist, flag implicit)
if (ctl->server.skip || outlevel == O_VERBOSE)
printf(" This host will%s be queried when no host is specified.\n",
ctl->server.skip ? " not" : "");
- /* don't poll for password when there is one or when using the ETRN
- ** protocol */
- if (!ctl->password && (ctl->server.protocol != P_ETRN))
+ /*
+ * Don't poll for password when there is one or when using the ETRN
+ * or IMAP-GSS protocol
+ */
+ if (!ctl->password && (ctl->server.protocol != P_ETRN)
+#ifdef GSSAPI
+ && (ctl->server.protocol != P_IMAP_GSS)
+#endif /* GSSAPI */
+ )
printf(" Password will be prompted for.\n");
else if (outlevel == O_VERBOSE)
if (ctl->server.protocol == P_APOP)